@@ -11,7 +11,7 @@ use vars qw/@ISA/;
 use DBI;
 
 
-our $VERSION = '0.021';
+our $VERSION = '0.2';
 
 
 =head1 NAME
@@ -21,8 +21,8 @@ AxKit::App::TABOO::Data::User::Contributor - Contributor Data objects for TABOO
 =head1 SYNOPSIS
 
   use AxKit::App::TABOO::Data::User::Contributor;
-  $user = AxKit::App::TABOO::Data::User::Contributor->new();
-  $user->load('kjetil');
+  $user = AxKit::App::TABOO::Data::User::Contributor->new(@dbconnectargs);
+  $user->load(what => '*', limit => {'username' => 'kjetil'});
   my $fullname = $user->load_authlevel('kjetil');
 
 =head1 DESCRIPTION
@@ -32,7 +32,7 @@ This Data class subclasses L<AxKit::App::TABOO::Data::User> to add an authentica
 
 =cut
 
-AxKit::App::TABOO::Data::User::Contributor->selectquery("SELECT * FROM users INNER JOIN contributors ON (users.username = contributors.username) WHERE users.username=?");
+AxKit::App::TABOO::Data::User::Contributor->dbfrom("users INNER JOIN contributors ON (users.username = contributors.username)");
 AxKit::App::TABOO::Data::User::Contributor->dbtable("users,contributors");
 AxKit::App::TABOO::Data::User::Contributor->elementorder("username, name, email, uri, passwd, bio, authlevel");
 
@@ -42,7 +42,7 @@ This class implements two methods, the rest is inherited from L<AxKit::App::TABO
 
 =over
 
-=item C<new()>
+=item C<new(@dbconnectargs)>
 
 The constructor. Makes sure that we inherit the data members from our superclass. Apart from that, nothing special.
 
@@ -51,7 +51,7 @@ The constructor. Makes sure that we inherit the data members from our superclass
 sub new {
     my $that  = shift;
     my $class = ref($that) || $that;
-    my $self = $class->SUPER::new();
+    my $self = $class->SUPER::new(@_);
     $self->{authlevel} = 0;
     $self->{bio} = undef;
     bless($self, $class);
@@ -60,6 +60,32 @@ sub new {
 
 
 
+# We reimplement the load method with no changes to the API. Actually,
+# the reason is to preserve the API, we need to do it because we're
+# getting data from two tables, and they both have a username field.
+
+sub load {
+  my ($self, %args) = @_;
+  my $tmp = $args{'limit'}{'username'};
+  if ($tmp) {
+    delete $args{'limit'}{'username'};
+    $args{'limit'}{'users.username'} = $tmp;
+  }
+
+  my $data = $self->_load(%args);
+  if ($data) {
+    ${$self}{'ONFILE'} = 1;
+  } else {
+    return undef;
+  }
+  foreach my $key (keys(%{$data})) {
+    ${$self}{$key} = ${$data}{$key}; 
+  }
+  return $self;
+}
+
+
+
 =item C<load_authlevel($username)>
 
 This is an ad hoc method to retrieve the authorization level of a user, and it takes a C<$username> key to identify whose level to retrieve. It will return a number that may be used to decide whether or not to grant access to an object or a data member. It will also populate the corresponding data fields of the object. You may therefore call C<write_xml> on the object afterwards and have markup for the username and level. 
@@ -69,14 +95,7 @@ This is an ad hoc method to retrieve the authorization level of a user, and it t
 sub load_authlevel {
     my $self = shift;
     my $username = shift;
-    my $dbh = DBI->connect($self->dbstring(), 
-			   $self->dbuser(), 
-			   $self->dbpasswd(),  
-#			   { PrintError => 0,
-# 			     RaiseError => 0,
-#			     HandleError => Exception::Class::DBI->handler
-#			     }
-);
+    my $dbh = DBI->connect($self->dbconnectargs());
     my $sth = $dbh->prepare("SELECT authlevel FROM contributors WHERE username=?");
     $sth->execute($username);
     my @data = $sth->fetchrow_array;
@@ -99,13 +118,8 @@ The C<save()> method has been reimplemented in this class. It is less generic th
 
 sub save {
   my $self = shift;
-  my $dbh = DBI->connect($self->dbstring(),
-			 $self->dbuser(),
-			 $self->dbpasswd(),
-			 { PrintError => 1,
-			   RaiseError => 0,
-			   HandleError => Exception::Class::DBI->handler,
-			   });
+  my $dbh = DBI->connect($self->dbconnectargs());
+  my $seq_id;
   my (@fields, @confields);
   my $i=0;
   my $j=0;
@@ -129,14 +143,17 @@ sub save {
     if (($i == 0) && ($j == 0)) {
       carp "No data fields with anything to save";
     } else {
-      my ($sth1, $sth2);
+      my ($sth1, $sth2, $query);
       if (${$self}{'ONFILE'}) {
 	$sth1 = $dbh->prepare("UPDATE users SET " . join('=?,', @fields) . "=? WHERE username=?");
 	$sth2 = $dbh->prepare("UPDATE contributors SET " . join('=?,', @confields) . "=? WHERE username=?");
       } else {
-	$sth1 = $dbh->prepare("INSERT INTO users (" . join(',', @fields) . ") VALUES (" . '?,' x ($i-1) . '?)');
-  	$sth2 = $dbh->prepare("INSERT INTO contributors (" . join(',', @confields) . ") VALUES (" . '?,' x ($j-1) . '?)');
+	($seq_id) = $dbh->selectrow_array("SELECT NEXTVAL('users_id_seq')");
+	$sth1 = $dbh->prepare("INSERT INTO users (" . join(',', @fields) . ",ID) VALUES (" . '?,' x $i . '?)');
+	$query = "INSERT INTO contributors (" . join(',', @confields) . ",Users_ID) VALUES (" . '?,' x $j . '?)';
+  	$sth2 = $dbh->prepare($query);
       }
+      warn "QUERY: $query";
       my $k=1;
       foreach my $key (@fields) {
 	$sth1->bind_param($k, ${$self}{$key});
@@ -144,6 +161,8 @@ sub save {
       }
       if (${$self}{'ONFILE'}) {
 	  $sth1->bind_param($k, ${$self}{'username'});
+      } else {
+	$sth1->bind_param($k, $seq_id);
       }
       $k=1;
       foreach my $key (@confields) {
@@ -152,6 +171,8 @@ sub save {
       }
       if (${$self}{'ONFILE'}) {
 	  $sth2->bind_param($k, ${$self}{'username'});
+      } else {
+	$sth2->bind_param($k, $seq_id);
       }
       if ($i > 0) {
 	$sth1->execute();
